import { isPlatformServer } from '@angular/common';
import * as i0 from '@angular/core';
import { PLATFORM_ID, Inject, Directive } from '@angular/core';
import { map, BehaviorSubject } from 'rxjs';

class BsObserveSizeDirective {
    element;
    platformId;
    zone;
    constructor(element, platformId, zone) {
        this.element = element;
        this.platformId = platformId;
        this.zone = zone;
        if (!isPlatformServer(this.platformId)) {
            this.observer = new ResizeObserver((entries) => {
                // console.log('resized', entries[0].contentRect);
                this.zone.run(() => this.size$.next(entries[0].contentRect));
            });
        }
        this.width$ = this.size$.pipe(map(size => size?.width));
        this.height$ = this.size$.pipe(map(size => size?.height));
    }
    observer;
    size$ = new BehaviorSubject(undefined);
    width$;
    height$;
    ngAfterViewInit() {
        const el = this.element.nativeElement;
        this.observer?.observe(el);
        this.size$.next({ width: el.clientWidth, height: el.clientHeight });
    }
    ngOnDestroy() {
        if (this.observer) {
            this.observer.unobserve(this.element.nativeElement);
            this.observer.disconnect();
        }
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.0", ngImport: i0, type: BsObserveSizeDirective, deps: [{ token: i0.ElementRef }, { token: PLATFORM_ID }, { token: i0.NgZone }], target: i0.ɵɵFactoryTarget.Directive });
    static ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "20.0.0", type: BsObserveSizeDirective, isStandalone: true, selector: "[bsObserveSize]", exportAs: ["bsObserveSize"], ngImport: i0 });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.0", ngImport: i0, type: BsObserveSizeDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[bsObserveSize]',
                    standalone: true,
                    exportAs: 'bsObserveSize'
                }]
        }], ctorParameters: () => [{ type: i0.ElementRef }, { type: undefined, decorators: [{
                    type: Inject,
                    args: [PLATFORM_ID]
                }] }, { type: i0.NgZone }] });

/**
 * Generated bundle index. Do not edit.
 */

export { BsObserveSizeDirective };
//# sourceMappingURL=mintplayer-ng-swiper-observe-size.mjs.map
